@@ -3,9 +3,10 @@ package Toolforge::MixNMatch::Object::YearMonth;
 use strict;
 use warnings;
 
-use Mo qw(is required);
+use Mo qw(build is);
+use Mo::utils qw(check_required);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 has count => (
 	is => 'ro',
@@ -22,6 +23,16 @@ has year => (
 	required => 1,
 );
 
+sub BUILD {
+	my $self = shift;
+
+	check_required($self, 'count');
+	check_required($self, 'month');
+	check_required($self, 'year');
+
+	return;
+}
+
 1;
 
 __END__
